@@ -18,7 +18,7 @@ from omfit_classes.utils_math import cicle_fourier_smooth
 import numpy as np
 import scipy.interpolate as interpolate
 
-__all__ = ['OMFITchease', 'OMFITcheaseLog', 'OMFITnuplo']
+__all__ = ['OMFITchease', 'OMFITcheaseLog', 'OMFITexptnz', 'OMFITnuplo']
 
 
 class OMFITchease(SortedDict, OMFITascii):
@@ -516,6 +516,63 @@ class OMFITcheaseLog(SortedDict, OMFITascii):
         return self
 
 
+class OMFITexptnz(SortedDict, OMFITascii):
+    r"""
+    OMFIT class used to interface with EXPTNZ files containing kinetic profiles
+
+    :param filename: filename passed to OMFITascii class
+
+    :param \**kw: keyword dictionary passed to OMFITascii class
+    """
+
+    def __init__(self, filename, **kw):
+        SortedDict.__init__(self)
+        OMFITascii.__init__(self, filename, **kw)
+        self.dynaLoad = True
+
+    @dynaLoad
+    def load(self):
+        with open(self.filename, 'r') as f:
+            header = f.readline().split()
+        if not len(header):
+            return
+        npoints = int(header[0])
+        tmp = np.loadtxt(self.filename, skiprows=1)
+        nprofs = int(len(tmp) / npoints)
+        for k in range(nprofs):
+            if ',' in header[k + 1]:
+                name = header[k + 1][:-1]
+            else:
+                name = header[k + 1]
+            if name == 'rhopsi':
+                rhopsi = tmp[: (k + 1) * npoints]
+                self['rhopsi'] = xarray.DataArray(
+                    rhopsi, dims=['rhopsi'], coords={'rhopsi': rhopsi}, attrs={'Description': 'Normalized poloidal flux'}
+                )
+                continue
+            else:
+                tmp2 = tmp[(k) * npoints : (k + 1) * npoints]
+                self[name] = xarray.DataArray(tmp2, dims=['rhopsi'], coords={'rhopsi': self['rhopsi']})
+
+    def exptnz2mars(self):
+        from omfit_classes.omfit_mars import OMFITmarsProfile
+
+        outprofs = {}
+        for item in self:
+            if item == 'rhopsi':
+                continue
+            proffile = item + '_prof'
+            with open(proffile, 'w') as f:
+                tmp = np.vstack(list([self['rhopsi'], self[item]])).T
+                shape = list(tmp.shape)
+                shape[1] = shape[1] - 1
+                f.write(' '.join(map(str, shape)) + '\n')
+                for k in range(tmp.shape[0]):
+                    f.write(' '.join(['%5.9e' % x for x in tmp[k, :]]) + '\n')
+            outprofs[item] = OMFITmarsProfile(proffile)
+        return outprofs
+
+
 class OMFITnuplo(SortedDict, OMFITascii):
     """CHEASE NUPLO output file"""
 
