@@ -1027,7 +1027,9 @@ def plot_style_enforcement(ax=None, plot_style=None):
     if ncol == 0:
         ncol = 1
     tag = f'{"cx" if show_cx else ""}-{ncol}-{settings.get("profiles", {}).get("num_profiles", 0)}'
-    layout = settings['plot_style_kw'].setdefault('subplot_layout', SettingsName()).setdefault(tag, SettingsName())
+    layout = (
+        settings.setdefault('plot_style_kw', SettingsName()).setdefault('subplot_layout', SettingsName()).setdefault(tag, SettingsName())
+    )
     fig.subplots_adjust(**layout)
 
     # Annotations
@@ -1786,8 +1788,8 @@ def plot_single_cx_ods(
             print(time.time() - timing_ref, 'omfitlib efitviewer unpack stuff')
 
         # Get machine and shot info
-        device = tokamak(ods['dataset_description.data_entry'].get('machine', settings['cases'][0]['device']))
-        shot = ods['dataset_description.data_entry'].get('pulse', evalExpr(settings['cases'][0]['shot']))
+        device = tokamak(ods['dataset_description.data_entry'].get('machine', settings.get('cases', {}).get(0, {}).get('device', None)))
+        shot = ods['dataset_description.data_entry'].get('pulse', evalExpr(settings.get('cases', {}).get(0, {}).get('shot', None)))
         try:
             efitid = ods['dataset_description.ids_properties.comment'].split('EFIT tree = ')[-1]
         except ValueError:
