@@ -198,5 +198,11 @@ eped_nn = eped_nn_fann
 ############################################
 if '__main__' == __name__:
     test_classes_main_header()
-    print(eped_nn(0.5, 1.0, 2.5, 0.6, 1.8, 1.9, 2.0, 3.6, 1.7, 2.0))
-    print(eped_nn([0.5, 0.5], [1.0, 1.0], [2.5, 2.5], [0.6, 0.6], [1.8, 1.8], [1.9, 1.9], [2.0, 2.0], [3.6, 3.6], [1.7, 1.7], [2.0, 2.0]))
+    print(eped_nn_fann(0.5, 1.0, 2.5, 0.6, 1.8, 1.9, 2.0, 3.6, 1.7, 2.0))
+    print(
+        eped_nn_fann([0.5, 0.5], [1.0, 1.0], [2.5, 2.5], [0.6, 0.6], [1.8, 1.8], [1.9, 1.9], [2.0, 2.0], [3.6, 3.6], [1.7, 1.7], [2.0, 2.0])
+    )
+    print(eped_nn_tf(0.5, 1.0, 2.5, 0.6, 1.8, 1.9, 2.0, 3.6, 1.7, 2.0))
+    print(
+        eped_nn_tf([0.5, 0.5], [1.0, 1.0], [2.5, 2.5], [0.6, 0.6], [1.8, 1.8], [1.9, 1.9], [2.0, 2.0], [3.6, 3.6], [1.7, 1.7], [2.0, 2.0])
+    )
