@@ -1415,7 +1415,7 @@ class OMFITd3dcompfile(SortedDict, OMFITascii):
                 compshot = int(eval(linesplit[0]))
                 self[compshot] = {}
                 for compsig in linesplit[1:]:
-                    self[compshot][compsig] = {}
+                    self[compshot][compsig.strip("'")] = {}
 
             except Exception:
                 sig = linesplit[0][1:].strip()
