@@ -252,7 +252,7 @@ class OMFITtranspData(SortedDict):
                 'transp_output of class %s is not recognized. Must be either %s or %s' % (transp_output.__class__, OMFITmds, OMFITnc)
             )
 
-    def plot(self, axes=None, label='RPLABEL', slice_axis=None, slice_at=[], **kw):
+    def plot(self, axes=None, label='RPLABEL', slice_axis=None, slice_at=[], label_show_slice=True, **kw):
         """
         Plot TRANSP data, using default metadata.
 
@@ -315,6 +315,7 @@ class OMFITtranspData(SortedDict):
             x = self['DIM_OF'][0][0]
             t = self['DIM_OF'][1][:, 0]
             y = self['DATA']
+
             x0label = '{:} [{:}]'.format(self['XAXIS'], self['UNITS_DIM_OF'][0]).replace('[]', '')
             x1label = '{:} [{:}]'.format('Time', self['UNITS_DIM_OF'][1]).replace('[]', '')
 
@@ -367,7 +368,9 @@ class OMFITtranspData(SortedDict):
                 for yi in yy:
                     lines += axes.plot(xx, yi, **kw)
                 if len(slice_at) == 1:
-                    label += ', {:}={:}'.format(slice_label.split()[0], slice_at[0])
+                    if label_show_slice:
+                        label += ', {:}={:}'.format(slice_label.split()[0], slice_at[0])
+
                 else:
                     sm = utils_plot.set_linearray(lines, slice_at)
                     cb = fig.colorbar(sm)
