@@ -293,8 +293,11 @@ def close(which_fig):
 
     """
     if which_fig == 'all':
-        for fn in list(_active_FigureNotebooks.keys()):
-            _active_FigureNotebooks[fn].close()
+        try:
+            for fn in list(_active_FigureNotebooks.keys()):
+                _active_FigureNotebooks[fn].close()
+        except NameError:
+            pass
         pyplot._original_close('all')
 
     else:
@@ -437,7 +440,11 @@ class OMFITfigure(object):  # SortedDict):
         self.figure = self.canvas.figure
 
         try:
-            self.tkRoot = self.canvas._master
+            if hasattr(self.canvas, '_master'):
+                self.tkRoot = self.canvas._master
+            elif hasattr(getattr(self.canvas, '_tkcanvas', None), 'master'):
+                self.tkRoot = self.canvas._tkcanvas.master
+
             self.focus = self.tkRoot.focus_get()
         except Exception:
             self.tkRoot = None
@@ -1516,12 +1523,12 @@ def _new_figure_manager_given_figure(*args):
             # log the failure, but carry on
             # verbose.report('Could not load matplotlib icon: %s' % sys.exc_info()[1])
             pass
-
-    canvas = pyplot._backend_mod.FigureCanvasTkAgg(figure, master=window)
-    if hasattr(pyplot._backend_mod, 'FigureManagerTk'):
-        figManager = pyplot._backend_mod.FigureManagerTk(canvas, num, window)
+    backend_mod = getattr(pyplot, '_get_backend_mod', lambda: pyplot._backend_mod)()
+    canvas = backend_mod.FigureCanvasTkAgg(figure, master=window)
+    if hasattr(backend_mod, 'FigureManagerTk'):
+        figManager = backend_mod.FigureManagerTk(canvas, num, window)
     else:
-        figManager = pyplot._backend_mod.FigureManagerTkAgg(canvas, num, window)
+        figManager = backend_mod.FigureManagerTkAgg(canvas, num, window)
     if OMFITaux['rootGUI'] is not None:
         tk_center(window, OMFITaux['rootGUI'], xoff=(np.mod(num - 1, 20) - 10) * 25, yoff=(np.mod(num - 1, 10) - 5) * 25)
     if OMFITaux['rootGUI'] is not None and OMFITaux['rootGUI'].globalgetvar('figsOnTop'):
@@ -1535,11 +1542,14 @@ if hasattr(matplotlib.backends, '_backend_tk'):
     _patch(matplotlib.backends._backend_tk._BackendTk, _new_figure_manager_given_figure)
 else:
     _patch(matplotlib.backends.backend_tkagg, _new_figure_manager_given_figure)
-_patch(pyplot._backend_mod, _new_figure_manager_given_figure)
+
+backend_mod = getattr(pyplot, '_get_backend_mod', lambda: pyplot._backend_mod)()
+if backend_mod is not None:
+    _patch(backend_mod, _new_figure_manager_given_figure)
 
 # hijack pyplot new_figure_manager to automatically enable OMFITfigure features on newly created figures
 def _new_figure_manager(num, figsize=(8, 6), FigureClass=Figure, **kw):
-    figureManager = getattr(matplotlib.backends, 'backend_' + matplotlib.backends.backend.lower()).new_figure_manager(
+    figureManager = getattr(matplotlib.backends, 'backend_' + matplotlib.get_backend().lower()).new_figure_manager(
         num, figsize=figsize, FigureClass=FigureClass, **kw
     )
 
@@ -1753,7 +1763,10 @@ class FigureNotebook(object):
             return self.figures[label]
         fig_kwargs['figsize'] = self.figsize
         tab = tk.Frame(self.notebook)
-        if not label:
+        num = fig_kwargs.pop('num', None)
+        if num is not None and label == '':
+            label = num
+        if not label and not num:
             label = 'Figure {:}'.format(len(self.figures) + 1)
         self.notebook.add(tab, text=label)
         self.notebook.pack()
@@ -1883,9 +1896,6 @@ class FigureNotebook(object):
         # function is passed some bogus arguments
         try:
             fig, ax = pyplot.subplots(nrows=nrows, ncols=ncols, **subplots_kwargs)
-        except Exception as _excp:
-            print('Unable to create tabbed subplots: %s' % repr(_excp))
-            fig = ax = None
         finally:
             pyplot.figure = original_figure
 
